@@ -15,6 +15,20 @@ pub struct DrawDiff<'a> {
 }
 
 impl DrawDiff<'_> {
+    /// Make a new instance of the diff drawer
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use termdiff::{arrows_theme, DrawDiff};
+    /// assert_eq!(
+    ///     format!("{}", DrawDiff::new("Hello", "World", arrows_theme())),
+    ///     "< left / > right
+    /// <Hello
+    /// >World
+    /// "
+    /// );
+    /// ```
     #[must_use]
     pub const fn new<'a>(old: &'a str, new: &'a str, theme: Theme) -> DrawDiff<'a> {
         DrawDiff { old, new, theme }
@@ -82,6 +96,12 @@ impl Display for DrawDiff<'_> {
     }
 }
 
+impl From<DrawDiff<'_>> for String {
+    fn from(diff: DrawDiff<'_>) -> Self {
+        format!("{}", diff)
+    }
+}
+
 #[cfg(test)]
 mod test {
     use super::{
@@ -136,6 +156,22 @@ mod test {
         );
     }
 
+    #[test]
+    fn into_string() {
+        let old = "Good Error\nBad Success";
+        let new = "Bad Error\nGood Success";
+        let actual: String = DrawDiff::new(old, new, arrows_theme()).into();
+        assert_eq!(
+            actual,
+            "< left / > right
+<Good Error
+<Bad Success
+>Bad Error
+>Good Success
+"
+        );
+    }
+
     #[test]
     fn its_customisable() {
         let old = "Good Error\nBad Success";
